@@ -1,6 +1,6 @@
 /*
 	ccid_usb.c: USB access routines using the libusb library
-	Copyright (C) 2003-2010	Ludovic Rousseau
+	Copyright (C) 2003-2025	Ludovic Rousseau
 
 	This library is free software; you can redistribute it and/or
 	modify it under the terms of the GNU Lesser General Public
@@ -896,6 +896,11 @@ again:
 						usbDevice[reader_index].ccid.sec1210_other_interface -> sec1210_other_interface = &usbDevice[reader_index].ccid;
 						/* share the cond struct */
 						usbDevice[reader_index].ccid.sec1210_shared = usbDevice[other_interface_index].ccid.sec1210_shared;
+						/* signal change if first interface comes after second */
+						if (interface == 0) {
+							DEBUG_INFO1("SEC1210: First interface came second, signaling");
+							pthread_cond_signal(&usbDevice[reader_index].ccid.sec1210_shared->sec1210_cond);
+						}
 					}
 					else
 					{
@@ -1420,6 +1425,80 @@ uint8_t get_ccid_usb_device_address(int reader_index)
 	return usbDevice[reader_index].device_address;
 }
 
+/*****************************************************************************
+ *
+ *					get_ccid_usb_device_path
+ *
+ ****************************************************************************/
+int get_ccid_usb_device_path(int reader_index, unsigned char *buf,
+	unsigned int *buflen)
+{
+	// Maximum amount of ports is 7 per USB 3.0 spec
+    uint8_t ports[7];
+    int nports;
+	int s;
+    unsigned int len = 0;
+	struct libusb_config_descriptor *cfg = NULL;
+	int res = IFD_SUCCESS;
+
+    if (!buf || !buflen || *buflen == 0) {
+        res = IFD_ERROR_INSUFFICIENT_BUFFER;
+		goto end;
+	}
+
+	libusb_device_handle *handle = usbDevice[reader_index].dev_handle;
+	if (!handle) {
+		res = IFD_COMMUNICATION_ERROR;
+		goto end;
+	}
+
+    libusb_device *dev = libusb_get_device(handle);
+    dev = libusb_get_device(handle);
+    if (!dev) {
+        res = IFD_COMMUNICATION_ERROR;
+		goto end;
+	}
+
+    nports = libusb_get_port_numbers(dev, ports, sizeof(ports));
+    if (nports < 0) {
+        res = IFD_COMMUNICATION_ERROR;
+		goto end;
+	}
+
+	if (libusb_get_active_config_descriptor(dev, &cfg) != 0) {
+		res = IFD_COMMUNICATION_ERROR;
+		goto end;
+	}
+
+    s = snprintf((char *)buf, *buflen, "%u-%u", libusb_get_bus_number(dev),
+		ports[0]);
+	if (s < 0 || (len += s) >= *buflen) {
+		res = IFD_ERROR_INSUFFICIENT_BUFFER;
+		goto end;
+	}
+
+    for (int i = 1; i < nports; i++) {
+        s = snprintf((char *)buf + len, *buflen - len, ".%u", ports[i]);
+		if (s < 0 || (len += s) >= *buflen) {
+			res = IFD_ERROR_INSUFFICIENT_BUFFER;
+			goto end;
+		}
+	}
+
+	s = snprintf((char *)buf + len, *buflen - len, ":%u.%u",
+		cfg->bConfigurationValue, usbDevice[reader_index].interface);
+	if (s < 0 || (len += s) >= *buflen) {
+		res = IFD_ERROR_INSUFFICIENT_BUFFER;
+		goto end;
+	}
+
+	*buflen = len + 1; // Account for null character
+
+end:
+	libusb_free_config_descriptor(cfg);
+	return res;
+}
+
 /*****************************************************************************
  *
  *					get_ccid_usb_interface
